Vero Python
===========

Version 1.1.4
-------------

Released on June 5, 2015

- Bumped requests library to 2.7.0
- Adds support for Python 3.4

Version 1.1.3
-------------

Released on July 11, 2013

- Updated VERO_BASE_URL
- Thanks @damienbrz
